#!/usr/bin/env python
# -*- coding: utf-8 -*-

# holt sich die version.new vom server und copiert sie nach version
import sys
import shutil
import os
import subprocess
import logging
import requests

# Konfiguration
LOGDIR="/tmp"
LOGFILE=os.path.join(LOGDIR, "kitte888_oscam_new_version.log")

# Logging einrichten
logging.basicConfig(filename=LOGFILE, level=logging.INFO, format='%(asctime)s - %(message)s')
logging.info("**************************** START *******************************")


def download_file(remote_url, local_path):
	print("-----------------------        Download Versionsfile        ---------------------")
	"""
	Lädt eine Datei von einer Remote-URL herunter und speichert sie lokal ab.

	:param remote_url: Die URL der Datei.
	:param local_path: Der lokale Pfad, an dem die Datei gespeichert wird.
	:return: Der Inhalt der Datei als String, falls erfolgreich, sonst None.
	"""
	logging.info("Starte Download: {}".format(remote_url))
	try:
		response = requests.get(remote_url, timeout=10)
		if response.status_code == 200:
			logging.info("Download erfolgreich, speichere Datei...")
			with open(local_path, "wb") as file:
				file.write(response.content)
			logging.info("Datei gespeichert: {}".format(local_path))

			with open(local_path, "r") as file:
				content = file.read().strip()
			return content
		else:
			logging.info("Fehler beim Download: Statuscode {}".format(response.status_code))
			return None
	except requests.RequestException as e:
		logging.info("Fehler bei der Anfrage: {}".format(e))
		return None

def update_version():
    # Pfad zur OSCam-Informationsdatei
    OSCAM_INFO_FILE = "/tmp/.oscam/oscam.version"  # Beispiel: /usr/local/etc/oscam

    # Zielort im /tmp-Ordner
    TMP_FILE = "/tmp/oscam.version"

    # Datei in /tmp kopieren
    try:
        shutil.copy(OSCAM_INFO_FILE, TMP_FILE)
    except FileNotFoundError:
        print("Fehler: Die Datei {} existiert nicht!".format(OSCAM_INFO_FILE))
        exit(1)

    # Prüfen, ob die Datei existiert
    if os.path.exists(TMP_FILE):
        camversion = "99999"

        #with open(TMP_FILE, "r", encoding="utf-8") as file:
        with open(TMP_FILE, "r") as file:
            for line in file:
                if "Version" in line:
                    print("cam version gefunden")
                    camversion = line.split(":")[-1].strip()
                      # Split anhand von "-" und die zweite Komponente nehmen
                    parts = camversion.split("-")
                    if len(parts) > 2:
                        camversion = parts[1]  # Nimmt den zweiten Teil (z. B. "11865")
                    break  # Sobald die Version gefunden wurde, die Schleife beenden

        if camversion:
            print("cam version ausgabe: {}".format(camversion))
        else:
            print("cam version nicht gefunden")
    else:
        print("Fehler: Die temporäre Datei wurde nicht gefunden!")

    # ------------------------------------------- hier path vom server wo es gehlot wird ---------------
    remote_url = "https://magentacloud.de/s/dBmmC8JEjiyYTy8/download?path=%2F&files=version.new"

    # ------------------------------------------ hier wo es reincopiert wird ---------------------------
    local_path = "/etc/tuxbox/config/oscamicamall/versionen/version.new"
    # --------------------------------------------------------------------------------------------------

    logging.info("Starte Versionsaktualisierung...")
    version_number = download_file(remote_url, local_path)
    version_numberlocal = camversion
    if version_number:
        # Hier wird die GUI oder Logik aktualisiert
        logging.info("Neue Version gefunden: {}".format(version_number))

        print(version_number)
        print("-----------------------        Server Version: {}        ---------------------".format(version_number))
        print("-----------------------        Locale Version: {}        ---------------------".format(version_numberlocal))

        if version_number > version_numberlocal:
          print( "-----   Server Version ist neuer download die neue Version mit script oscam_new_download   -----")
        else:
          print( "-----   Server Version ist gleich oder kleiner   -----")


    else:
      logging.info("Fehler beim Herunterladen der neuen Version.")
      print("fehler download")

if __name__ == "__main__":
	print("-----------------------        check Server Version        ---------------------")
	update_version()
